# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IpsArgs', 'Ips']

@pulumi.input_type
class IpsArgs:
    def __init__(__self__, *,
                 ad_blocked_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 advanced_filtering_preference: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_filters: Optional[pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]]] = None,
                 enabled_categories: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enabled_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 honeypots: Optional[pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]]] = None,
                 ips_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 memory_optimized: Optional[pulumi.Input[_builtins.bool]] = None,
                 restrict_torrents: Optional[pulumi.Input[_builtins.bool]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 suppression: Optional[pulumi.Input['IpsSuppressionArgs']] = None):
        """
        The set of arguments for constructing a Ips resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ad_blocked_networks: List of network IDs to enable ad blocking for. If any networks are configured, ad blocking will be automatically enabled. Each entry should be a valid network ID from your UniFi configuration. Leave empty to disable ad blocking.
        :param pulumi.Input[_builtins.str] advanced_filtering_preference: The advanced filtering preference for IPS. Valid values are:
                 * `disabled` - Advanced filtering is disabled
                 * `manual` - Advanced filtering is enabled and manually configured
        :param pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]] dns_filters: DNS filters configuration. If any filters are configured, DNS filtering will be automatically enabled. Each filter can be applied to a specific network and provides content filtering capabilities.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_categories: List of enabled IPS threat categories. Each entry enables detection and prevention for a specific type of threat. The list of valid categories includes common threats like malware, exploits, scanning, and policy violations. See the validator for the complete list of available categories.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_networks: List of network IDs to enable IPS protection for. Each entry should be a valid network ID from your UniFi configuration. IPS will only monitor and protect traffic on these networks.
        :param pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]] honeypots: Honeypots configuration. Honeypots are decoy systems designed to detect, deflect, or study hacking attempts. They appear as legitimate parts of the network but are isolated and monitored.
        :param pulumi.Input[_builtins.str] ips_mode: The IPS operation mode. Valid values are:
                 * `ids` - Intrusion Detection System mode (detect and log threats only)
                 * `ips` - Intrusion Prevention System mode (detect and block threats)
                 * `ipsInline` - Inline Intrusion Prevention System mode (more aggressive blocking)
                 * `disabled` - IPS functionality is completely disabled
        :param pulumi.Input[_builtins.bool] memory_optimized: Whether memory optimization is enabled for IPS. When set to `true`, the system will use less memory at the cost of potentially reduced detection capabilities. Useful for devices with limited resources. Defaults to `false`. Requires controller version 9.0 or later.
        :param pulumi.Input[_builtins.bool] restrict_torrents: Whether to restrict BitTorrent and other peer-to-peer file sharing traffic. When set to `true`, the system will block P2P traffic across the network. Defaults to `false`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input['IpsSuppressionArgs'] suppression: Suppression configuration for IPS. This allows you to customize which alerts are suppressed or tracked, and define whitelisted traffic that should never trigger IPS alerts.
        """
        if ad_blocked_networks is not None:
            pulumi.set(__self__, "ad_blocked_networks", ad_blocked_networks)
        if advanced_filtering_preference is not None:
            pulumi.set(__self__, "advanced_filtering_preference", advanced_filtering_preference)
        if dns_filters is not None:
            pulumi.set(__self__, "dns_filters", dns_filters)
        if enabled_categories is not None:
            pulumi.set(__self__, "enabled_categories", enabled_categories)
        if enabled_networks is not None:
            pulumi.set(__self__, "enabled_networks", enabled_networks)
        if honeypots is not None:
            pulumi.set(__self__, "honeypots", honeypots)
        if ips_mode is not None:
            pulumi.set(__self__, "ips_mode", ips_mode)
        if memory_optimized is not None:
            pulumi.set(__self__, "memory_optimized", memory_optimized)
        if restrict_torrents is not None:
            pulumi.set(__self__, "restrict_torrents", restrict_torrents)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if suppression is not None:
            pulumi.set(__self__, "suppression", suppression)

    @_builtins.property
    @pulumi.getter(name="adBlockedNetworks")
    def ad_blocked_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of network IDs to enable ad blocking for. If any networks are configured, ad blocking will be automatically enabled. Each entry should be a valid network ID from your UniFi configuration. Leave empty to disable ad blocking.
        """
        return pulumi.get(self, "ad_blocked_networks")

    @ad_blocked_networks.setter
    def ad_blocked_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ad_blocked_networks", value)

    @_builtins.property
    @pulumi.getter(name="advancedFilteringPreference")
    def advanced_filtering_preference(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The advanced filtering preference for IPS. Valid values are:
          * `disabled` - Advanced filtering is disabled
          * `manual` - Advanced filtering is enabled and manually configured
        """
        return pulumi.get(self, "advanced_filtering_preference")

    @advanced_filtering_preference.setter
    def advanced_filtering_preference(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "advanced_filtering_preference", value)

    @_builtins.property
    @pulumi.getter(name="dnsFilters")
    def dns_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]]]:
        """
        DNS filters configuration. If any filters are configured, DNS filtering will be automatically enabled. Each filter can be applied to a specific network and provides content filtering capabilities.
        """
        return pulumi.get(self, "dns_filters")

    @dns_filters.setter
    def dns_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]]]):
        pulumi.set(self, "dns_filters", value)

    @_builtins.property
    @pulumi.getter(name="enabledCategories")
    def enabled_categories(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of enabled IPS threat categories. Each entry enables detection and prevention for a specific type of threat. The list of valid categories includes common threats like malware, exploits, scanning, and policy violations. See the validator for the complete list of available categories.
        """
        return pulumi.get(self, "enabled_categories")

    @enabled_categories.setter
    def enabled_categories(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enabled_categories", value)

    @_builtins.property
    @pulumi.getter(name="enabledNetworks")
    def enabled_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of network IDs to enable IPS protection for. Each entry should be a valid network ID from your UniFi configuration. IPS will only monitor and protect traffic on these networks.
        """
        return pulumi.get(self, "enabled_networks")

    @enabled_networks.setter
    def enabled_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enabled_networks", value)

    @_builtins.property
    @pulumi.getter
    def honeypots(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]]]:
        """
        Honeypots configuration. Honeypots are decoy systems designed to detect, deflect, or study hacking attempts. They appear as legitimate parts of the network but are isolated and monitored.
        """
        return pulumi.get(self, "honeypots")

    @honeypots.setter
    def honeypots(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]]]):
        pulumi.set(self, "honeypots", value)

    @_builtins.property
    @pulumi.getter(name="ipsMode")
    def ips_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPS operation mode. Valid values are:
          * `ids` - Intrusion Detection System mode (detect and log threats only)
          * `ips` - Intrusion Prevention System mode (detect and block threats)
          * `ipsInline` - Inline Intrusion Prevention System mode (more aggressive blocking)
          * `disabled` - IPS functionality is completely disabled
        """
        return pulumi.get(self, "ips_mode")

    @ips_mode.setter
    def ips_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ips_mode", value)

    @_builtins.property
    @pulumi.getter(name="memoryOptimized")
    def memory_optimized(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether memory optimization is enabled for IPS. When set to `true`, the system will use less memory at the cost of potentially reduced detection capabilities. Useful for devices with limited resources. Defaults to `false`. Requires controller version 9.0 or later.
        """
        return pulumi.get(self, "memory_optimized")

    @memory_optimized.setter
    def memory_optimized(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "memory_optimized", value)

    @_builtins.property
    @pulumi.getter(name="restrictTorrents")
    def restrict_torrents(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to restrict BitTorrent and other peer-to-peer file sharing traffic. When set to `true`, the system will block P2P traffic across the network. Defaults to `false`.
        """
        return pulumi.get(self, "restrict_torrents")

    @restrict_torrents.setter
    def restrict_torrents(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "restrict_torrents", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter
    def suppression(self) -> Optional[pulumi.Input['IpsSuppressionArgs']]:
        """
        Suppression configuration for IPS. This allows you to customize which alerts are suppressed or tracked, and define whitelisted traffic that should never trigger IPS alerts.
        """
        return pulumi.get(self, "suppression")

    @suppression.setter
    def suppression(self, value: Optional[pulumi.Input['IpsSuppressionArgs']]):
        pulumi.set(self, "suppression", value)


@pulumi.input_type
class _IpsState:
    def __init__(__self__, *,
                 ad_blocked_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 advanced_filtering_preference: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_filters: Optional[pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]]] = None,
                 enabled_categories: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enabled_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 honeypots: Optional[pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]]] = None,
                 ips_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 memory_optimized: Optional[pulumi.Input[_builtins.bool]] = None,
                 restrict_torrents: Optional[pulumi.Input[_builtins.bool]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 suppression: Optional[pulumi.Input['IpsSuppressionArgs']] = None):
        """
        Input properties used for looking up and filtering Ips resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ad_blocked_networks: List of network IDs to enable ad blocking for. If any networks are configured, ad blocking will be automatically enabled. Each entry should be a valid network ID from your UniFi configuration. Leave empty to disable ad blocking.
        :param pulumi.Input[_builtins.str] advanced_filtering_preference: The advanced filtering preference for IPS. Valid values are:
                 * `disabled` - Advanced filtering is disabled
                 * `manual` - Advanced filtering is enabled and manually configured
        :param pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]] dns_filters: DNS filters configuration. If any filters are configured, DNS filtering will be automatically enabled. Each filter can be applied to a specific network and provides content filtering capabilities.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_categories: List of enabled IPS threat categories. Each entry enables detection and prevention for a specific type of threat. The list of valid categories includes common threats like malware, exploits, scanning, and policy violations. See the validator for the complete list of available categories.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_networks: List of network IDs to enable IPS protection for. Each entry should be a valid network ID from your UniFi configuration. IPS will only monitor and protect traffic on these networks.
        :param pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]] honeypots: Honeypots configuration. Honeypots are decoy systems designed to detect, deflect, or study hacking attempts. They appear as legitimate parts of the network but are isolated and monitored.
        :param pulumi.Input[_builtins.str] ips_mode: The IPS operation mode. Valid values are:
                 * `ids` - Intrusion Detection System mode (detect and log threats only)
                 * `ips` - Intrusion Prevention System mode (detect and block threats)
                 * `ipsInline` - Inline Intrusion Prevention System mode (more aggressive blocking)
                 * `disabled` - IPS functionality is completely disabled
        :param pulumi.Input[_builtins.bool] memory_optimized: Whether memory optimization is enabled for IPS. When set to `true`, the system will use less memory at the cost of potentially reduced detection capabilities. Useful for devices with limited resources. Defaults to `false`. Requires controller version 9.0 or later.
        :param pulumi.Input[_builtins.bool] restrict_torrents: Whether to restrict BitTorrent and other peer-to-peer file sharing traffic. When set to `true`, the system will block P2P traffic across the network. Defaults to `false`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input['IpsSuppressionArgs'] suppression: Suppression configuration for IPS. This allows you to customize which alerts are suppressed or tracked, and define whitelisted traffic that should never trigger IPS alerts.
        """
        if ad_blocked_networks is not None:
            pulumi.set(__self__, "ad_blocked_networks", ad_blocked_networks)
        if advanced_filtering_preference is not None:
            pulumi.set(__self__, "advanced_filtering_preference", advanced_filtering_preference)
        if dns_filters is not None:
            pulumi.set(__self__, "dns_filters", dns_filters)
        if enabled_categories is not None:
            pulumi.set(__self__, "enabled_categories", enabled_categories)
        if enabled_networks is not None:
            pulumi.set(__self__, "enabled_networks", enabled_networks)
        if honeypots is not None:
            pulumi.set(__self__, "honeypots", honeypots)
        if ips_mode is not None:
            pulumi.set(__self__, "ips_mode", ips_mode)
        if memory_optimized is not None:
            pulumi.set(__self__, "memory_optimized", memory_optimized)
        if restrict_torrents is not None:
            pulumi.set(__self__, "restrict_torrents", restrict_torrents)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if suppression is not None:
            pulumi.set(__self__, "suppression", suppression)

    @_builtins.property
    @pulumi.getter(name="adBlockedNetworks")
    def ad_blocked_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of network IDs to enable ad blocking for. If any networks are configured, ad blocking will be automatically enabled. Each entry should be a valid network ID from your UniFi configuration. Leave empty to disable ad blocking.
        """
        return pulumi.get(self, "ad_blocked_networks")

    @ad_blocked_networks.setter
    def ad_blocked_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ad_blocked_networks", value)

    @_builtins.property
    @pulumi.getter(name="advancedFilteringPreference")
    def advanced_filtering_preference(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The advanced filtering preference for IPS. Valid values are:
          * `disabled` - Advanced filtering is disabled
          * `manual` - Advanced filtering is enabled and manually configured
        """
        return pulumi.get(self, "advanced_filtering_preference")

    @advanced_filtering_preference.setter
    def advanced_filtering_preference(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "advanced_filtering_preference", value)

    @_builtins.property
    @pulumi.getter(name="dnsFilters")
    def dns_filters(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]]]:
        """
        DNS filters configuration. If any filters are configured, DNS filtering will be automatically enabled. Each filter can be applied to a specific network and provides content filtering capabilities.
        """
        return pulumi.get(self, "dns_filters")

    @dns_filters.setter
    def dns_filters(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpsDnsFilterArgs']]]]):
        pulumi.set(self, "dns_filters", value)

    @_builtins.property
    @pulumi.getter(name="enabledCategories")
    def enabled_categories(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of enabled IPS threat categories. Each entry enables detection and prevention for a specific type of threat. The list of valid categories includes common threats like malware, exploits, scanning, and policy violations. See the validator for the complete list of available categories.
        """
        return pulumi.get(self, "enabled_categories")

    @enabled_categories.setter
    def enabled_categories(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enabled_categories", value)

    @_builtins.property
    @pulumi.getter(name="enabledNetworks")
    def enabled_networks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of network IDs to enable IPS protection for. Each entry should be a valid network ID from your UniFi configuration. IPS will only monitor and protect traffic on these networks.
        """
        return pulumi.get(self, "enabled_networks")

    @enabled_networks.setter
    def enabled_networks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "enabled_networks", value)

    @_builtins.property
    @pulumi.getter
    def honeypots(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]]]:
        """
        Honeypots configuration. Honeypots are decoy systems designed to detect, deflect, or study hacking attempts. They appear as legitimate parts of the network but are isolated and monitored.
        """
        return pulumi.get(self, "honeypots")

    @honeypots.setter
    def honeypots(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpsHoneypotArgs']]]]):
        pulumi.set(self, "honeypots", value)

    @_builtins.property
    @pulumi.getter(name="ipsMode")
    def ips_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IPS operation mode. Valid values are:
          * `ids` - Intrusion Detection System mode (detect and log threats only)
          * `ips` - Intrusion Prevention System mode (detect and block threats)
          * `ipsInline` - Inline Intrusion Prevention System mode (more aggressive blocking)
          * `disabled` - IPS functionality is completely disabled
        """
        return pulumi.get(self, "ips_mode")

    @ips_mode.setter
    def ips_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ips_mode", value)

    @_builtins.property
    @pulumi.getter(name="memoryOptimized")
    def memory_optimized(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether memory optimization is enabled for IPS. When set to `true`, the system will use less memory at the cost of potentially reduced detection capabilities. Useful for devices with limited resources. Defaults to `false`. Requires controller version 9.0 or later.
        """
        return pulumi.get(self, "memory_optimized")

    @memory_optimized.setter
    def memory_optimized(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "memory_optimized", value)

    @_builtins.property
    @pulumi.getter(name="restrictTorrents")
    def restrict_torrents(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to restrict BitTorrent and other peer-to-peer file sharing traffic. When set to `true`, the system will block P2P traffic across the network. Defaults to `false`.
        """
        return pulumi.get(self, "restrict_torrents")

    @restrict_torrents.setter
    def restrict_torrents(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "restrict_torrents", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter
    def suppression(self) -> Optional[pulumi.Input['IpsSuppressionArgs']]:
        """
        Suppression configuration for IPS. This allows you to customize which alerts are suppressed or tracked, and define whitelisted traffic that should never trigger IPS alerts.
        """
        return pulumi.get(self, "suppression")

    @suppression.setter
    def suppression(self, value: Optional[pulumi.Input['IpsSuppressionArgs']]):
        pulumi.set(self, "suppression", value)


@pulumi.type_token("unifi:setting/ips:Ips")
class Ips(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ad_blocked_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 advanced_filtering_preference: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpsDnsFilterArgs', 'IpsDnsFilterArgsDict']]]]] = None,
                 enabled_categories: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enabled_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 honeypots: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpsHoneypotArgs', 'IpsHoneypotArgsDict']]]]] = None,
                 ips_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 memory_optimized: Optional[pulumi.Input[_builtins.bool]] = None,
                 restrict_torrents: Optional[pulumi.Input[_builtins.bool]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 suppression: Optional[pulumi.Input[Union['IpsSuppressionArgs', 'IpsSuppressionArgsDict']]] = None,
                 __props__=None):
        """
        The `setting.Ips` resource allows you to configure the Intrusion Prevention System (IPS) settings for your UniFi network. IPS provides network threat protection by monitoring, detecting, and preventing malicious traffic based on configured rules and policies. Requires controller version 7.4 or later

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.Network("test",
            name="My Network",
            purpose="corporate",
            subnet="192.168.1.0/24",
            vlan_id=10)
        example = unifi.setting.Ips("example",
            ips_mode="ips",
            enabled_networks=[test.id],
            advanced_filtering_preference="manual",
            enabled_categories=[
                "emerging-dos",
                "emerging-exploit",
                "emerging-malware",
            ],
            ad_blocked_networks=[test.id],
            honeypots=[{
                "ip_address": "192.168.1.10",
                "network_id": test.id,
            }],
            dns_filters=[{
                "name": "Work Filter",
                "filter": "work",
                "description": "Block non-work related sites",
                "allowed_sites": [
                    "example.com",
                    "company.com",
                ],
                "blocked_sites": [
                    "gaming.example.com",
                    "social.example.com",
                ],
                "blocked_tld": ["xyz"],
            }])
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ad_blocked_networks: List of network IDs to enable ad blocking for. If any networks are configured, ad blocking will be automatically enabled. Each entry should be a valid network ID from your UniFi configuration. Leave empty to disable ad blocking.
        :param pulumi.Input[_builtins.str] advanced_filtering_preference: The advanced filtering preference for IPS. Valid values are:
                 * `disabled` - Advanced filtering is disabled
                 * `manual` - Advanced filtering is enabled and manually configured
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpsDnsFilterArgs', 'IpsDnsFilterArgsDict']]]] dns_filters: DNS filters configuration. If any filters are configured, DNS filtering will be automatically enabled. Each filter can be applied to a specific network and provides content filtering capabilities.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_categories: List of enabled IPS threat categories. Each entry enables detection and prevention for a specific type of threat. The list of valid categories includes common threats like malware, exploits, scanning, and policy violations. See the validator for the complete list of available categories.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_networks: List of network IDs to enable IPS protection for. Each entry should be a valid network ID from your UniFi configuration. IPS will only monitor and protect traffic on these networks.
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpsHoneypotArgs', 'IpsHoneypotArgsDict']]]] honeypots: Honeypots configuration. Honeypots are decoy systems designed to detect, deflect, or study hacking attempts. They appear as legitimate parts of the network but are isolated and monitored.
        :param pulumi.Input[_builtins.str] ips_mode: The IPS operation mode. Valid values are:
                 * `ids` - Intrusion Detection System mode (detect and log threats only)
                 * `ips` - Intrusion Prevention System mode (detect and block threats)
                 * `ipsInline` - Inline Intrusion Prevention System mode (more aggressive blocking)
                 * `disabled` - IPS functionality is completely disabled
        :param pulumi.Input[_builtins.bool] memory_optimized: Whether memory optimization is enabled for IPS. When set to `true`, the system will use less memory at the cost of potentially reduced detection capabilities. Useful for devices with limited resources. Defaults to `false`. Requires controller version 9.0 or later.
        :param pulumi.Input[_builtins.bool] restrict_torrents: Whether to restrict BitTorrent and other peer-to-peer file sharing traffic. When set to `true`, the system will block P2P traffic across the network. Defaults to `false`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[Union['IpsSuppressionArgs', 'IpsSuppressionArgsDict']] suppression: Suppression configuration for IPS. This allows you to customize which alerts are suppressed or tracked, and define whitelisted traffic that should never trigger IPS alerts.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[IpsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `setting.Ips` resource allows you to configure the Intrusion Prevention System (IPS) settings for your UniFi network. IPS provides network threat protection by monitoring, detecting, and preventing malicious traffic based on configured rules and policies. Requires controller version 7.4 or later

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        test = unifi.Network("test",
            name="My Network",
            purpose="corporate",
            subnet="192.168.1.0/24",
            vlan_id=10)
        example = unifi.setting.Ips("example",
            ips_mode="ips",
            enabled_networks=[test.id],
            advanced_filtering_preference="manual",
            enabled_categories=[
                "emerging-dos",
                "emerging-exploit",
                "emerging-malware",
            ],
            ad_blocked_networks=[test.id],
            honeypots=[{
                "ip_address": "192.168.1.10",
                "network_id": test.id,
            }],
            dns_filters=[{
                "name": "Work Filter",
                "filter": "work",
                "description": "Block non-work related sites",
                "allowed_sites": [
                    "example.com",
                    "company.com",
                ],
                "blocked_sites": [
                    "gaming.example.com",
                    "social.example.com",
                ],
                "blocked_tld": ["xyz"],
            }])
        ```

        :param str resource_name: The name of the resource.
        :param IpsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IpsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 ad_blocked_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 advanced_filtering_preference: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpsDnsFilterArgs', 'IpsDnsFilterArgsDict']]]]] = None,
                 enabled_categories: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enabled_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 honeypots: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpsHoneypotArgs', 'IpsHoneypotArgsDict']]]]] = None,
                 ips_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 memory_optimized: Optional[pulumi.Input[_builtins.bool]] = None,
                 restrict_torrents: Optional[pulumi.Input[_builtins.bool]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 suppression: Optional[pulumi.Input[Union['IpsSuppressionArgs', 'IpsSuppressionArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IpsArgs.__new__(IpsArgs)

            __props__.__dict__["ad_blocked_networks"] = ad_blocked_networks
            __props__.__dict__["advanced_filtering_preference"] = advanced_filtering_preference
            __props__.__dict__["dns_filters"] = dns_filters
            __props__.__dict__["enabled_categories"] = enabled_categories
            __props__.__dict__["enabled_networks"] = enabled_networks
            __props__.__dict__["honeypots"] = honeypots
            __props__.__dict__["ips_mode"] = ips_mode
            __props__.__dict__["memory_optimized"] = memory_optimized
            __props__.__dict__["restrict_torrents"] = restrict_torrents
            __props__.__dict__["site"] = site
            __props__.__dict__["suppression"] = suppression
        super(Ips, __self__).__init__(
            'unifi:setting/ips:Ips',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            ad_blocked_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            advanced_filtering_preference: Optional[pulumi.Input[_builtins.str]] = None,
            dns_filters: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpsDnsFilterArgs', 'IpsDnsFilterArgsDict']]]]] = None,
            enabled_categories: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            enabled_networks: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            honeypots: Optional[pulumi.Input[Sequence[pulumi.Input[Union['IpsHoneypotArgs', 'IpsHoneypotArgsDict']]]]] = None,
            ips_mode: Optional[pulumi.Input[_builtins.str]] = None,
            memory_optimized: Optional[pulumi.Input[_builtins.bool]] = None,
            restrict_torrents: Optional[pulumi.Input[_builtins.bool]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            suppression: Optional[pulumi.Input[Union['IpsSuppressionArgs', 'IpsSuppressionArgsDict']]] = None) -> 'Ips':
        """
        Get an existing Ips resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ad_blocked_networks: List of network IDs to enable ad blocking for. If any networks are configured, ad blocking will be automatically enabled. Each entry should be a valid network ID from your UniFi configuration. Leave empty to disable ad blocking.
        :param pulumi.Input[_builtins.str] advanced_filtering_preference: The advanced filtering preference for IPS. Valid values are:
                 * `disabled` - Advanced filtering is disabled
                 * `manual` - Advanced filtering is enabled and manually configured
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpsDnsFilterArgs', 'IpsDnsFilterArgsDict']]]] dns_filters: DNS filters configuration. If any filters are configured, DNS filtering will be automatically enabled. Each filter can be applied to a specific network and provides content filtering capabilities.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_categories: List of enabled IPS threat categories. Each entry enables detection and prevention for a specific type of threat. The list of valid categories includes common threats like malware, exploits, scanning, and policy violations. See the validator for the complete list of available categories.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] enabled_networks: List of network IDs to enable IPS protection for. Each entry should be a valid network ID from your UniFi configuration. IPS will only monitor and protect traffic on these networks.
        :param pulumi.Input[Sequence[pulumi.Input[Union['IpsHoneypotArgs', 'IpsHoneypotArgsDict']]]] honeypots: Honeypots configuration. Honeypots are decoy systems designed to detect, deflect, or study hacking attempts. They appear as legitimate parts of the network but are isolated and monitored.
        :param pulumi.Input[_builtins.str] ips_mode: The IPS operation mode. Valid values are:
                 * `ids` - Intrusion Detection System mode (detect and log threats only)
                 * `ips` - Intrusion Prevention System mode (detect and block threats)
                 * `ipsInline` - Inline Intrusion Prevention System mode (more aggressive blocking)
                 * `disabled` - IPS functionality is completely disabled
        :param pulumi.Input[_builtins.bool] memory_optimized: Whether memory optimization is enabled for IPS. When set to `true`, the system will use less memory at the cost of potentially reduced detection capabilities. Useful for devices with limited resources. Defaults to `false`. Requires controller version 9.0 or later.
        :param pulumi.Input[_builtins.bool] restrict_torrents: Whether to restrict BitTorrent and other peer-to-peer file sharing traffic. When set to `true`, the system will block P2P traffic across the network. Defaults to `false`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[Union['IpsSuppressionArgs', 'IpsSuppressionArgsDict']] suppression: Suppression configuration for IPS. This allows you to customize which alerts are suppressed or tracked, and define whitelisted traffic that should never trigger IPS alerts.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IpsState.__new__(_IpsState)

        __props__.__dict__["ad_blocked_networks"] = ad_blocked_networks
        __props__.__dict__["advanced_filtering_preference"] = advanced_filtering_preference
        __props__.__dict__["dns_filters"] = dns_filters
        __props__.__dict__["enabled_categories"] = enabled_categories
        __props__.__dict__["enabled_networks"] = enabled_networks
        __props__.__dict__["honeypots"] = honeypots
        __props__.__dict__["ips_mode"] = ips_mode
        __props__.__dict__["memory_optimized"] = memory_optimized
        __props__.__dict__["restrict_torrents"] = restrict_torrents
        __props__.__dict__["site"] = site
        __props__.__dict__["suppression"] = suppression
        return Ips(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="adBlockedNetworks")
    def ad_blocked_networks(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of network IDs to enable ad blocking for. If any networks are configured, ad blocking will be automatically enabled. Each entry should be a valid network ID from your UniFi configuration. Leave empty to disable ad blocking.
        """
        return pulumi.get(self, "ad_blocked_networks")

    @_builtins.property
    @pulumi.getter(name="advancedFilteringPreference")
    def advanced_filtering_preference(self) -> pulumi.Output[_builtins.str]:
        """
        The advanced filtering preference for IPS. Valid values are:
          * `disabled` - Advanced filtering is disabled
          * `manual` - Advanced filtering is enabled and manually configured
        """
        return pulumi.get(self, "advanced_filtering_preference")

    @_builtins.property
    @pulumi.getter(name="dnsFilters")
    def dns_filters(self) -> pulumi.Output[Sequence['outputs.IpsDnsFilter']]:
        """
        DNS filters configuration. If any filters are configured, DNS filtering will be automatically enabled. Each filter can be applied to a specific network and provides content filtering capabilities.
        """
        return pulumi.get(self, "dns_filters")

    @_builtins.property
    @pulumi.getter(name="enabledCategories")
    def enabled_categories(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of enabled IPS threat categories. Each entry enables detection and prevention for a specific type of threat. The list of valid categories includes common threats like malware, exploits, scanning, and policy violations. See the validator for the complete list of available categories.
        """
        return pulumi.get(self, "enabled_categories")

    @_builtins.property
    @pulumi.getter(name="enabledNetworks")
    def enabled_networks(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of network IDs to enable IPS protection for. Each entry should be a valid network ID from your UniFi configuration. IPS will only monitor and protect traffic on these networks.
        """
        return pulumi.get(self, "enabled_networks")

    @_builtins.property
    @pulumi.getter
    def honeypots(self) -> pulumi.Output[Sequence['outputs.IpsHoneypot']]:
        """
        Honeypots configuration. Honeypots are decoy systems designed to detect, deflect, or study hacking attempts. They appear as legitimate parts of the network but are isolated and monitored.
        """
        return pulumi.get(self, "honeypots")

    @_builtins.property
    @pulumi.getter(name="ipsMode")
    def ips_mode(self) -> pulumi.Output[_builtins.str]:
        """
        The IPS operation mode. Valid values are:
          * `ids` - Intrusion Detection System mode (detect and log threats only)
          * `ips` - Intrusion Prevention System mode (detect and block threats)
          * `ipsInline` - Inline Intrusion Prevention System mode (more aggressive blocking)
          * `disabled` - IPS functionality is completely disabled
        """
        return pulumi.get(self, "ips_mode")

    @_builtins.property
    @pulumi.getter(name="memoryOptimized")
    def memory_optimized(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether memory optimization is enabled for IPS. When set to `true`, the system will use less memory at the cost of potentially reduced detection capabilities. Useful for devices with limited resources. Defaults to `false`. Requires controller version 9.0 or later.
        """
        return pulumi.get(self, "memory_optimized")

    @_builtins.property
    @pulumi.getter(name="restrictTorrents")
    def restrict_torrents(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to restrict BitTorrent and other peer-to-peer file sharing traffic. When set to `true`, the system will block P2P traffic across the network. Defaults to `false`.
        """
        return pulumi.get(self, "restrict_torrents")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter
    def suppression(self) -> pulumi.Output['outputs.IpsSuppression']:
        """
        Suppression configuration for IPS. This allows you to customize which alerts are suppressed or tracked, and define whitelisted traffic that should never trigger IPS alerts.
        """
        return pulumi.get(self, "suppression")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .auto_speedtest import *
from .country import *
from .dpi import *
from .guest_access import *
from .ips import *
from .lcd_monitor import *
from .locale import *
from .magic_site_to_site_vpn import *
from .mgmt import *
from .network_optimization import *
from .ntp import *
from .radius import *
from .rsyslogd import *
from .ssl_inspection import *
from .teleport import *
from .usg import *
from .usw import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetRecordResult',
    'AwaitableGetRecordResult',
    'get_record',
    'get_record_output',
]

@pulumi.output_type
class GetRecordResult:
    """
    A collection of values returned by getRecord.
    """
    def __init__(__self__, enabled=None, id=None, name=None, port=None, priority=None, site=None, ttl=None, type=None, value=None, weight=None):
        if enabled and not isinstance(enabled, bool):
            raise TypeError("Expected argument 'enabled' to be a bool")
        pulumi.set(__self__, "enabled", enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if priority and not isinstance(priority, int):
            raise TypeError("Expected argument 'priority' to be a int")
        pulumi.set(__self__, "priority", priority)
        if site and not isinstance(site, str):
            raise TypeError("Expected argument 'site' to be a str")
        pulumi.set(__self__, "site", site)
        if ttl and not isinstance(ttl, int):
            raise TypeError("Expected argument 'ttl' to be a int")
        pulumi.set(__self__, "ttl", ttl)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if value and not isinstance(value, str):
            raise TypeError("Expected argument 'value' to be a str")
        pulumi.set(__self__, "value", value)
        if weight and not isinstance(weight, int):
            raise TypeError("Expected argument 'weight' to be a int")
        pulumi.set(__self__, "weight", weight)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> _builtins.bool:
        """
        Whether the DNS record is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        DNS record name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> _builtins.int:
        """
        The port of the DNS record.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> _builtins.int:
        """
        Priority of the DNS records. Present only for MX and SRV records; unused by other record types.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def site(self) -> _builtins.str:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> _builtins.int:
        """
        Time To Live (TTL) of the DNS record in seconds. Setting to 0 means 'automatic'.
        """
        return pulumi.get(self, "ttl")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        The type of the DNS record.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        DNS record content.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter
    def weight(self) -> _builtins.int:
        """
        A numeric value indicating the relative weight of the record.
        """
        return pulumi.get(self, "weight")


class AwaitableGetRecordResult(GetRecordResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRecordResult(
            enabled=self.enabled,
            id=self.id,
            name=self.name,
            port=self.port,
            priority=self.priority,
            site=self.site,
            ttl=self.ttl,
            type=self.type,
            value=self.value,
            weight=self.weight)


def get_record(name: Optional[_builtins.str] = None,
               site: Optional[_builtins.str] = None,
               value: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRecordResult:
    """
    Retrieves information about a specific DNS record configured in your UniFi network. This data source allows you to look up DNS records by either their name or record content. It's particularly useful for validating existing DNS configurations or referencing DNS records in other resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_unifi as unifi

    by_name = unifi.dns.get_record(name="example.mydomain.com")
    by_record = unifi.dns.get_record(value="192.168.0.1")
    ```


    :param _builtins.str name: DNS record name.
    :param _builtins.str site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
    :param _builtins.str value: DNS record content.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    __args__['value'] = value
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('unifi:dns/getRecord:getRecord', __args__, opts=opts, typ=GetRecordResult).value

    return AwaitableGetRecordResult(
        enabled=pulumi.get(__ret__, 'enabled'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        port=pulumi.get(__ret__, 'port'),
        priority=pulumi.get(__ret__, 'priority'),
        site=pulumi.get(__ret__, 'site'),
        ttl=pulumi.get(__ret__, 'ttl'),
        type=pulumi.get(__ret__, 'type'),
        value=pulumi.get(__ret__, 'value'),
        weight=pulumi.get(__ret__, 'weight'))
def get_record_output(name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      site: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      value: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRecordResult]:
    """
    Retrieves information about a specific DNS record configured in your UniFi network. This data source allows you to look up DNS records by either their name or record content. It's particularly useful for validating existing DNS configurations or referencing DNS records in other resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_unifi as unifi

    by_name = unifi.dns.get_record(name="example.mydomain.com")
    by_record = unifi.dns.get_record(value="192.168.0.1")
    ```


    :param _builtins.str name: DNS record name.
    :param _builtins.str site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
    :param _builtins.str value: DNS record content.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    __args__['value'] = value
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('unifi:dns/getRecord:getRecord', __args__, opts=opts, typ=GetRecordResult)
    return __ret__.apply(lambda __response__: GetRecordResult(
        enabled=pulumi.get(__response__, 'enabled'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        port=pulumi.get(__response__, 'port'),
        priority=pulumi.get(__response__, 'priority'),
        site=pulumi.get(__response__, 'site'),
        ttl=pulumi.get(__response__, 'ttl'),
        type=pulumi.get(__response__, 'type'),
        value=pulumi.get(__response__, 'value'),
        weight=pulumi.get(__response__, 'weight')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ForwardArgs', 'Forward']

@pulumi.input_type
class ForwardArgs:
    def __init__(__self__, *,
                 dst_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 fwd_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 fwd_port: Optional[pulumi.Input[_builtins.str]] = None,
                 log: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_forward_interface: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 src_ip: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Forward resource.
        :param pulumi.Input[_builtins.str] dst_port: The external port(s) that will be forwarded. Can be a single port (e.g., '80') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether the port forwarding rule is enabled or not.
        :param pulumi.Input[_builtins.str] fwd_ip: The internal IPv4 address of the device or service that will receive the forwarded traffic (e.g., '192.168.1.100').
        :param pulumi.Input[_builtins.str] fwd_port: The internal port(s) that will receive the forwarded traffic. Can be a single port (e.g., '8080') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] log: Enable logging of traffic matching this port forwarding rule. Useful for monitoring and troubleshooting.
        :param pulumi.Input[_builtins.str] name: A friendly name for the port forwarding rule to help identify its purpose (e.g., 'Web Server' or 'Game Server').
        :param pulumi.Input[_builtins.str] port_forward_interface: The WAN interface to apply the port forwarding rule to. Valid values are:
                 * `wan` - Primary WAN interface
                 * `wan2` - Secondary WAN interface
                 * `both` - Both WAN interfaces
        :param pulumi.Input[_builtins.str] protocol: The network protocol(s) this rule applies to. Valid values are:
                 * `tcp_udp` - Both TCP and UDP (default)
                 * `tcp` - TCP only
                 * `udp` - UDP only
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the port forwarding rule should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.str] src_ip: The source IP address or network in CIDR notation that is allowed to use this port forward. Use 'any' to allow all source IPs. Examples: '203.0.113.1' for a single IP, '203.0.113.0/24' for a network, or 'any' for all IPs.
        """
        if dst_port is not None:
            pulumi.set(__self__, "dst_port", dst_port)
        if enabled is not None:
            warnings.warn("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""", DeprecationWarning)
            pulumi.log.warn("""enabled is deprecated: This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if fwd_ip is not None:
            pulumi.set(__self__, "fwd_ip", fwd_ip)
        if fwd_port is not None:
            pulumi.set(__self__, "fwd_port", fwd_port)
        if log is not None:
            pulumi.set(__self__, "log", log)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_forward_interface is not None:
            pulumi.set(__self__, "port_forward_interface", port_forward_interface)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if src_ip is not None:
            pulumi.set(__self__, "src_ip", src_ip)

    @_builtins.property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The external port(s) that will be forwarded. Can be a single port (e.g., '80') or a port range (e.g., '8080:8090').
        """
        return pulumi.get(self, "dst_port")

    @dst_port.setter
    def dst_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dst_port", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether the port forwarding rule is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="fwdIp")
    def fwd_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The internal IPv4 address of the device or service that will receive the forwarded traffic (e.g., '192.168.1.100').
        """
        return pulumi.get(self, "fwd_ip")

    @fwd_ip.setter
    def fwd_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fwd_ip", value)

    @_builtins.property
    @pulumi.getter(name="fwdPort")
    def fwd_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The internal port(s) that will receive the forwarded traffic. Can be a single port (e.g., '8080') or a port range (e.g., '8080:8090').
        """
        return pulumi.get(self, "fwd_port")

    @fwd_port.setter
    def fwd_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fwd_port", value)

    @_builtins.property
    @pulumi.getter
    def log(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable logging of traffic matching this port forwarding rule. Useful for monitoring and troubleshooting.
        """
        return pulumi.get(self, "log")

    @log.setter
    def log(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "log", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the port forwarding rule to help identify its purpose (e.g., 'Web Server' or 'Game Server').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="portForwardInterface")
    def port_forward_interface(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The WAN interface to apply the port forwarding rule to. Valid values are:
          * `wan` - Primary WAN interface
          * `wan2` - Secondary WAN interface
          * `both` - Both WAN interfaces
        """
        return pulumi.get(self, "port_forward_interface")

    @port_forward_interface.setter
    def port_forward_interface(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "port_forward_interface", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The network protocol(s) this rule applies to. Valid values are:
          * `tcp_udp` - Both TCP and UDP (default)
          * `tcp` - TCP only
          * `udp` - UDP only
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the port forwarding rule should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="srcIp")
    def src_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The source IP address or network in CIDR notation that is allowed to use this port forward. Use 'any' to allow all source IPs. Examples: '203.0.113.1' for a single IP, '203.0.113.0/24' for a network, or 'any' for all IPs.
        """
        return pulumi.get(self, "src_ip")

    @src_ip.setter
    def src_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "src_ip", value)


@pulumi.input_type
class _ForwardState:
    def __init__(__self__, *,
                 dst_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 fwd_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 fwd_port: Optional[pulumi.Input[_builtins.str]] = None,
                 log: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_forward_interface: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 src_ip: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Forward resources.
        :param pulumi.Input[_builtins.str] dst_port: The external port(s) that will be forwarded. Can be a single port (e.g., '80') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether the port forwarding rule is enabled or not.
        :param pulumi.Input[_builtins.str] fwd_ip: The internal IPv4 address of the device or service that will receive the forwarded traffic (e.g., '192.168.1.100').
        :param pulumi.Input[_builtins.str] fwd_port: The internal port(s) that will receive the forwarded traffic. Can be a single port (e.g., '8080') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] log: Enable logging of traffic matching this port forwarding rule. Useful for monitoring and troubleshooting.
        :param pulumi.Input[_builtins.str] name: A friendly name for the port forwarding rule to help identify its purpose (e.g., 'Web Server' or 'Game Server').
        :param pulumi.Input[_builtins.str] port_forward_interface: The WAN interface to apply the port forwarding rule to. Valid values are:
                 * `wan` - Primary WAN interface
                 * `wan2` - Secondary WAN interface
                 * `both` - Both WAN interfaces
        :param pulumi.Input[_builtins.str] protocol: The network protocol(s) this rule applies to. Valid values are:
                 * `tcp_udp` - Both TCP and UDP (default)
                 * `tcp` - TCP only
                 * `udp` - UDP only
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the port forwarding rule should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.str] src_ip: The source IP address or network in CIDR notation that is allowed to use this port forward. Use 'any' to allow all source IPs. Examples: '203.0.113.1' for a single IP, '203.0.113.0/24' for a network, or 'any' for all IPs.
        """
        if dst_port is not None:
            pulumi.set(__self__, "dst_port", dst_port)
        if enabled is not None:
            warnings.warn("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""", DeprecationWarning)
            pulumi.log.warn("""enabled is deprecated: This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if fwd_ip is not None:
            pulumi.set(__self__, "fwd_ip", fwd_ip)
        if fwd_port is not None:
            pulumi.set(__self__, "fwd_port", fwd_port)
        if log is not None:
            pulumi.set(__self__, "log", log)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port_forward_interface is not None:
            pulumi.set(__self__, "port_forward_interface", port_forward_interface)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if src_ip is not None:
            pulumi.set(__self__, "src_ip", src_ip)

    @_builtins.property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The external port(s) that will be forwarded. Can be a single port (e.g., '80') or a port range (e.g., '8080:8090').
        """
        return pulumi.get(self, "dst_port")

    @dst_port.setter
    def dst_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dst_port", value)

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Specifies whether the port forwarding rule is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="fwdIp")
    def fwd_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The internal IPv4 address of the device or service that will receive the forwarded traffic (e.g., '192.168.1.100').
        """
        return pulumi.get(self, "fwd_ip")

    @fwd_ip.setter
    def fwd_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fwd_ip", value)

    @_builtins.property
    @pulumi.getter(name="fwdPort")
    def fwd_port(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The internal port(s) that will receive the forwarded traffic. Can be a single port (e.g., '8080') or a port range (e.g., '8080:8090').
        """
        return pulumi.get(self, "fwd_port")

    @fwd_port.setter
    def fwd_port(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "fwd_port", value)

    @_builtins.property
    @pulumi.getter
    def log(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable logging of traffic matching this port forwarding rule. Useful for monitoring and troubleshooting.
        """
        return pulumi.get(self, "log")

    @log.setter
    def log(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "log", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A friendly name for the port forwarding rule to help identify its purpose (e.g., 'Web Server' or 'Game Server').
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="portForwardInterface")
    def port_forward_interface(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The WAN interface to apply the port forwarding rule to. Valid values are:
          * `wan` - Primary WAN interface
          * `wan2` - Secondary WAN interface
          * `both` - Both WAN interfaces
        """
        return pulumi.get(self, "port_forward_interface")

    @port_forward_interface.setter
    def port_forward_interface(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "port_forward_interface", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The network protocol(s) this rule applies to. Valid values are:
          * `tcp_udp` - Both TCP and UDP (default)
          * `tcp` - TCP only
          * `udp` - UDP only
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where the port forwarding rule should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter(name="srcIp")
    def src_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The source IP address or network in CIDR notation that is allowed to use this port forward. Use 'any' to allow all source IPs. Examples: '203.0.113.1' for a single IP, '203.0.113.0/24' for a network, or 'any' for all IPs.
        """
        return pulumi.get(self, "src_ip")

    @src_ip.setter
    def src_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "src_ip", value)


@pulumi.type_token("unifi:port/forward:Forward")
class Forward(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dst_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 fwd_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 fwd_port: Optional[pulumi.Input[_builtins.str]] = None,
                 log: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_forward_interface: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 src_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `port.Forward` resource manages port forwarding rules on UniFi controllers.

        Port forwarding allows external traffic to reach services hosted on your internal network by mapping external ports to internal IP addresses and ports. This is commonly used for:
          * Hosting web servers, game servers, or other services
          * Remote access to internal services
          * Application-specific requirements

        Each rule can be configured with source IP restrictions, protocol selection, and logging options for enhanced security and monitoring.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dst_port: The external port(s) that will be forwarded. Can be a single port (e.g., '80') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether the port forwarding rule is enabled or not.
        :param pulumi.Input[_builtins.str] fwd_ip: The internal IPv4 address of the device or service that will receive the forwarded traffic (e.g., '192.168.1.100').
        :param pulumi.Input[_builtins.str] fwd_port: The internal port(s) that will receive the forwarded traffic. Can be a single port (e.g., '8080') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] log: Enable logging of traffic matching this port forwarding rule. Useful for monitoring and troubleshooting.
        :param pulumi.Input[_builtins.str] name: A friendly name for the port forwarding rule to help identify its purpose (e.g., 'Web Server' or 'Game Server').
        :param pulumi.Input[_builtins.str] port_forward_interface: The WAN interface to apply the port forwarding rule to. Valid values are:
                 * `wan` - Primary WAN interface
                 * `wan2` - Secondary WAN interface
                 * `both` - Both WAN interfaces
        :param pulumi.Input[_builtins.str] protocol: The network protocol(s) this rule applies to. Valid values are:
                 * `tcp_udp` - Both TCP and UDP (default)
                 * `tcp` - TCP only
                 * `udp` - UDP only
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the port forwarding rule should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.str] src_ip: The source IP address or network in CIDR notation that is allowed to use this port forward. Use 'any' to allow all source IPs. Examples: '203.0.113.1' for a single IP, '203.0.113.0/24' for a network, or 'any' for all IPs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ForwardArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `port.Forward` resource manages port forwarding rules on UniFi controllers.

        Port forwarding allows external traffic to reach services hosted on your internal network by mapping external ports to internal IP addresses and ports. This is commonly used for:
          * Hosting web servers, game servers, or other services
          * Remote access to internal services
          * Application-specific requirements

        Each rule can be configured with source IP restrictions, protocol selection, and logging options for enhanced security and monitoring.

        :param str resource_name: The name of the resource.
        :param ForwardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ForwardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dst_port: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 fwd_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 fwd_port: Optional[pulumi.Input[_builtins.str]] = None,
                 log: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port_forward_interface: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 src_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ForwardArgs.__new__(ForwardArgs)

            __props__.__dict__["dst_port"] = dst_port
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["fwd_ip"] = fwd_ip
            __props__.__dict__["fwd_port"] = fwd_port
            __props__.__dict__["log"] = log
            __props__.__dict__["name"] = name
            __props__.__dict__["port_forward_interface"] = port_forward_interface
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["site"] = site
            __props__.__dict__["src_ip"] = src_ip
        super(Forward, __self__).__init__(
            'unifi:port/forward:Forward',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            dst_port: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            fwd_ip: Optional[pulumi.Input[_builtins.str]] = None,
            fwd_port: Optional[pulumi.Input[_builtins.str]] = None,
            log: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            port_forward_interface: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            src_ip: Optional[pulumi.Input[_builtins.str]] = None) -> 'Forward':
        """
        Get an existing Forward resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] dst_port: The external port(s) that will be forwarded. Can be a single port (e.g., '80') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] enabled: Specifies whether the port forwarding rule is enabled or not.
        :param pulumi.Input[_builtins.str] fwd_ip: The internal IPv4 address of the device or service that will receive the forwarded traffic (e.g., '192.168.1.100').
        :param pulumi.Input[_builtins.str] fwd_port: The internal port(s) that will receive the forwarded traffic. Can be a single port (e.g., '8080') or a port range (e.g., '8080:8090').
        :param pulumi.Input[_builtins.bool] log: Enable logging of traffic matching this port forwarding rule. Useful for monitoring and troubleshooting.
        :param pulumi.Input[_builtins.str] name: A friendly name for the port forwarding rule to help identify its purpose (e.g., 'Web Server' or 'Game Server').
        :param pulumi.Input[_builtins.str] port_forward_interface: The WAN interface to apply the port forwarding rule to. Valid values are:
                 * `wan` - Primary WAN interface
                 * `wan2` - Secondary WAN interface
                 * `both` - Both WAN interfaces
        :param pulumi.Input[_builtins.str] protocol: The network protocol(s) this rule applies to. Valid values are:
                 * `tcp_udp` - Both TCP and UDP (default)
                 * `tcp` - TCP only
                 * `udp` - UDP only
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where the port forwarding rule should be created. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.str] src_ip: The source IP address or network in CIDR notation that is allowed to use this port forward. Use 'any' to allow all source IPs. Examples: '203.0.113.1' for a single IP, '203.0.113.0/24' for a network, or 'any' for all IPs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ForwardState.__new__(_ForwardState)

        __props__.__dict__["dst_port"] = dst_port
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["fwd_ip"] = fwd_ip
        __props__.__dict__["fwd_port"] = fwd_port
        __props__.__dict__["log"] = log
        __props__.__dict__["name"] = name
        __props__.__dict__["port_forward_interface"] = port_forward_interface
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["site"] = site
        __props__.__dict__["src_ip"] = src_ip
        return Forward(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="dstPort")
    def dst_port(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The external port(s) that will be forwarded. Can be a single port (e.g., '80') or a port range (e.g., '8080:8090').
        """
        return pulumi.get(self, "dst_port")

    @_builtins.property
    @pulumi.getter
    @_utilities.deprecated("""This will attribute will be removed in a future release. Instead of disabling a port forwarding rule you can remove it from your configuration.""")
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Specifies whether the port forwarding rule is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="fwdIp")
    def fwd_ip(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The internal IPv4 address of the device or service that will receive the forwarded traffic (e.g., '192.168.1.100').
        """
        return pulumi.get(self, "fwd_ip")

    @_builtins.property
    @pulumi.getter(name="fwdPort")
    def fwd_port(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The internal port(s) that will receive the forwarded traffic. Can be a single port (e.g., '8080') or a port range (e.g., '8080:8090').
        """
        return pulumi.get(self, "fwd_port")

    @_builtins.property
    @pulumi.getter
    def log(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable logging of traffic matching this port forwarding rule. Useful for monitoring and troubleshooting.
        """
        return pulumi.get(self, "log")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A friendly name for the port forwarding rule to help identify its purpose (e.g., 'Web Server' or 'Game Server').
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="portForwardInterface")
    def port_forward_interface(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The WAN interface to apply the port forwarding rule to. Valid values are:
          * `wan` - Primary WAN interface
          * `wan2` - Secondary WAN interface
          * `both` - Both WAN interfaces
        """
        return pulumi.get(self, "port_forward_interface")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The network protocol(s) this rule applies to. Valid values are:
          * `tcp_udp` - Both TCP and UDP (default)
          * `tcp` - TCP only
          * `udp` - UDP only
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where the port forwarding rule should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter(name="srcIp")
    def src_ip(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The source IP address or network in CIDR notation that is allowed to use this port forward. Use 'any' to allow all source IPs. Examples: '203.0.113.1' for a single IP, '203.0.113.0/24' for a network, or 'any' for all IPs.
        """
        return pulumi.get(self, "src_ip")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RecordArgs', 'Record']

@pulumi.input_type
class RecordArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[_builtins.str],
                 value: pulumi.Input[_builtins.str],
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a Record resource.
        :param pulumi.Input[_builtins.str] type: The type of DNS record. Valid values are:
                 * `A` - Maps a hostname to IPv4 address
                 * `AAAA` - Maps a hostname to IPv6 address
                 * `CNAME` - Creates an alias for another domain name
                 * `MX` - Specifies mail servers for the domain
                 * `NS` - Delegates a subdomain to a set of name servers
                 * `PTR` - Creates a pointer to a canonical name (reverse DNS)
                 * `SOA` - Specifies authoritative information about the domain
                 * `SRV` - Specifies location of services (hostname and port)
                 * `TXT` - Holds descriptive text
        :param pulumi.Input[_builtins.str] value: The content of the DNS record. The expected value depends on the record type:
                 * For A records: IPv4 address (e.g., '192.168.1.10')
                 * For AAAA records: IPv6 address
                 * For CNAME records: Canonical name (e.g., 'server1.example.com')
                 * For MX records: Mail server hostname
                 * For TXT records: Text content (e.g., 'v=spf1 include:_spf.example.com ~all')
        :param pulumi.Input[_builtins.bool] enabled: Whether the DNS record is active. Defaults to true. Set to false to temporarily disable resolution without removing the record.
        :param pulumi.Input[_builtins.str] name: DNS record name.
        :param pulumi.Input[_builtins.int] port: The port number for SRV records. Valid values are between 1 and 65535. Only used with SRV records.
        :param pulumi.Input[_builtins.int] priority: Priority value for MX and SRV records. Lower values indicate higher priority. Required for MX and SRV records, ignored for other types.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.int] ttl: Time To Live (TTL) in seconds, determines how long DNS resolvers should cache this record. Set to 0 for automatic TTL. Common values: 300 (5 minutes), 3600 (1 hour), 86400 (1 day).
        :param pulumi.Input[_builtins.int] weight: A relative weight for SRV records with the same priority. Higher values get proportionally more traffic. Only used with SRV records.
        """
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of DNS record. Valid values are:
          * `A` - Maps a hostname to IPv4 address
          * `AAAA` - Maps a hostname to IPv6 address
          * `CNAME` - Creates an alias for another domain name
          * `MX` - Specifies mail servers for the domain
          * `NS` - Delegates a subdomain to a set of name servers
          * `PTR` - Creates a pointer to a canonical name (reverse DNS)
          * `SOA` - Specifies authoritative information about the domain
          * `SRV` - Specifies location of services (hostname and port)
          * `TXT` - Holds descriptive text
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.str]:
        """
        The content of the DNS record. The expected value depends on the record type:
          * For A records: IPv4 address (e.g., '192.168.1.10')
          * For AAAA records: IPv6 address
          * For CNAME records: Canonical name (e.g., 'server1.example.com')
          * For MX records: Mail server hostname
          * For TXT records: Text content (e.g., 'v=spf1 include:_spf.example.com ~all')
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the DNS record is active. Defaults to true. Set to false to temporarily disable resolution without removing the record.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DNS record name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The port number for SRV records. Valid values are between 1 and 65535. Only used with SRV records.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Priority value for MX and SRV records. Lower values indicate higher priority. Required for MX and SRV records, ignored for other types.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time To Live (TTL) in seconds, determines how long DNS resolvers should cache this record. Set to 0 for automatic TTL. Common values: 300 (5 minutes), 3600 (1 hour), 86400 (1 day).
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ttl", value)

    @_builtins.property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        A relative weight for SRV records with the same priority. Higher values get proportionally more traffic. Only used with SRV records.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.input_type
class _RecordState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering Record resources.
        :param pulumi.Input[_builtins.bool] enabled: Whether the DNS record is active. Defaults to true. Set to false to temporarily disable resolution without removing the record.
        :param pulumi.Input[_builtins.str] name: DNS record name.
        :param pulumi.Input[_builtins.int] port: The port number for SRV records. Valid values are between 1 and 65535. Only used with SRV records.
        :param pulumi.Input[_builtins.int] priority: Priority value for MX and SRV records. Lower values indicate higher priority. Required for MX and SRV records, ignored for other types.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.int] ttl: Time To Live (TTL) in seconds, determines how long DNS resolvers should cache this record. Set to 0 for automatic TTL. Common values: 300 (5 minutes), 3600 (1 hour), 86400 (1 day).
        :param pulumi.Input[_builtins.str] type: The type of DNS record. Valid values are:
                 * `A` - Maps a hostname to IPv4 address
                 * `AAAA` - Maps a hostname to IPv6 address
                 * `CNAME` - Creates an alias for another domain name
                 * `MX` - Specifies mail servers for the domain
                 * `NS` - Delegates a subdomain to a set of name servers
                 * `PTR` - Creates a pointer to a canonical name (reverse DNS)
                 * `SOA` - Specifies authoritative information about the domain
                 * `SRV` - Specifies location of services (hostname and port)
                 * `TXT` - Holds descriptive text
        :param pulumi.Input[_builtins.str] value: The content of the DNS record. The expected value depends on the record type:
                 * For A records: IPv4 address (e.g., '192.168.1.10')
                 * For AAAA records: IPv6 address
                 * For CNAME records: Canonical name (e.g., 'server1.example.com')
                 * For MX records: Mail server hostname
                 * For TXT records: Text content (e.g., 'v=spf1 include:_spf.example.com ~all')
        :param pulumi.Input[_builtins.int] weight: A relative weight for SRV records with the same priority. Higher values get proportionally more traffic. Only used with SRV records.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if site is not None:
            pulumi.set(__self__, "site", site)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the DNS record is active. Defaults to true. Set to false to temporarily disable resolution without removing the record.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        DNS record name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The port number for SRV records. Valid values are between 1 and 65535. Only used with SRV records.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Priority value for MX and SRV records. Lower values indicate higher priority. Required for MX and SRV records, ignored for other types.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "priority", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Time To Live (TTL) in seconds, determines how long DNS resolvers should cache this record. Set to 0 for automatic TTL. Common values: 300 (5 minutes), 3600 (1 hour), 86400 (1 day).
        """
        return pulumi.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "ttl", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of DNS record. Valid values are:
          * `A` - Maps a hostname to IPv4 address
          * `AAAA` - Maps a hostname to IPv6 address
          * `CNAME` - Creates an alias for another domain name
          * `MX` - Specifies mail servers for the domain
          * `NS` - Delegates a subdomain to a set of name servers
          * `PTR` - Creates a pointer to a canonical name (reverse DNS)
          * `SOA` - Specifies authoritative information about the domain
          * `SRV` - Specifies location of services (hostname and port)
          * `TXT` - Holds descriptive text
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The content of the DNS record. The expected value depends on the record type:
          * For A records: IPv4 address (e.g., '192.168.1.10')
          * For AAAA records: IPv6 address
          * For CNAME records: Canonical name (e.g., 'server1.example.com')
          * For MX records: Mail server hostname
          * For TXT records: Text content (e.g., 'v=spf1 include:_spf.example.com ~all')
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        A relative weight for SRV records with the same priority. Higher values get proportionally more traffic. Only used with SRV records.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "weight", value)


@pulumi.type_token("unifi:dns/record:Record")
class Record(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        The `dns.Record` resource manages DNS records in the UniFi controller's DNS server.

        This resource allows you to configure various types of DNS records for local name resolution. Common use cases include:
          * Creating A records for local servers and devices
          * Setting up CNAME aliases for internal services
          * Configuring MX records for local mail servers
          * Adding TXT records for service verification

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        a_record = unifi.dns.Record("a_record",
            name="example.mydomain.com",
            type="A",
            value="192.168.1.190")
        cname_record = unifi.dns.Record("cname_record",
            name="example.mydomain.com",
            type="CNAME",
            value="example.com")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether the DNS record is active. Defaults to true. Set to false to temporarily disable resolution without removing the record.
        :param pulumi.Input[_builtins.str] name: DNS record name.
        :param pulumi.Input[_builtins.int] port: The port number for SRV records. Valid values are between 1 and 65535. Only used with SRV records.
        :param pulumi.Input[_builtins.int] priority: Priority value for MX and SRV records. Lower values indicate higher priority. Required for MX and SRV records, ignored for other types.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.int] ttl: Time To Live (TTL) in seconds, determines how long DNS resolvers should cache this record. Set to 0 for automatic TTL. Common values: 300 (5 minutes), 3600 (1 hour), 86400 (1 day).
        :param pulumi.Input[_builtins.str] type: The type of DNS record. Valid values are:
                 * `A` - Maps a hostname to IPv4 address
                 * `AAAA` - Maps a hostname to IPv6 address
                 * `CNAME` - Creates an alias for another domain name
                 * `MX` - Specifies mail servers for the domain
                 * `NS` - Delegates a subdomain to a set of name servers
                 * `PTR` - Creates a pointer to a canonical name (reverse DNS)
                 * `SOA` - Specifies authoritative information about the domain
                 * `SRV` - Specifies location of services (hostname and port)
                 * `TXT` - Holds descriptive text
        :param pulumi.Input[_builtins.str] value: The content of the DNS record. The expected value depends on the record type:
                 * For A records: IPv4 address (e.g., '192.168.1.10')
                 * For AAAA records: IPv6 address
                 * For CNAME records: Canonical name (e.g., 'server1.example.com')
                 * For MX records: Mail server hostname
                 * For TXT records: Text content (e.g., 'v=spf1 include:_spf.example.com ~all')
        :param pulumi.Input[_builtins.int] weight: A relative weight for SRV records with the same priority. Higher values get proportionally more traffic. Only used with SRV records.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RecordArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `dns.Record` resource manages DNS records in the UniFi controller's DNS server.

        This resource allows you to configure various types of DNS records for local name resolution. Common use cases include:
          * Creating A records for local servers and devices
          * Setting up CNAME aliases for internal services
          * Configuring MX records for local mail servers
          * Adding TXT records for service verification

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        a_record = unifi.dns.Record("a_record",
            name="example.mydomain.com",
            type="A",
            value="192.168.1.190")
        cname_record = unifi.dns.Record("cname_record",
            name="example.mydomain.com",
            type="CNAME",
            value="example.com")
        ```

        :param str resource_name: The name of the resource.
        :param RecordArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RecordArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 priority: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 ttl: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 weight: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RecordArgs.__new__(RecordArgs)

            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            __props__.__dict__["port"] = port
            __props__.__dict__["priority"] = priority
            __props__.__dict__["site"] = site
            __props__.__dict__["ttl"] = ttl
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = value
            __props__.__dict__["weight"] = weight
        super(Record, __self__).__init__(
            'unifi:dns/record:Record',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            priority: Optional[pulumi.Input[_builtins.int]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None,
            ttl: Optional[pulumi.Input[_builtins.int]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            weight: Optional[pulumi.Input[_builtins.int]] = None) -> 'Record':
        """
        Get an existing Record resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether the DNS record is active. Defaults to true. Set to false to temporarily disable resolution without removing the record.
        :param pulumi.Input[_builtins.str] name: DNS record name.
        :param pulumi.Input[_builtins.int] port: The port number for SRV records. Valid values are between 1 and 65535. Only used with SRV records.
        :param pulumi.Input[_builtins.int] priority: Priority value for MX and SRV records. Lower values indicate higher priority. Required for MX and SRV records, ignored for other types.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        :param pulumi.Input[_builtins.int] ttl: Time To Live (TTL) in seconds, determines how long DNS resolvers should cache this record. Set to 0 for automatic TTL. Common values: 300 (5 minutes), 3600 (1 hour), 86400 (1 day).
        :param pulumi.Input[_builtins.str] type: The type of DNS record. Valid values are:
                 * `A` - Maps a hostname to IPv4 address
                 * `AAAA` - Maps a hostname to IPv6 address
                 * `CNAME` - Creates an alias for another domain name
                 * `MX` - Specifies mail servers for the domain
                 * `NS` - Delegates a subdomain to a set of name servers
                 * `PTR` - Creates a pointer to a canonical name (reverse DNS)
                 * `SOA` - Specifies authoritative information about the domain
                 * `SRV` - Specifies location of services (hostname and port)
                 * `TXT` - Holds descriptive text
        :param pulumi.Input[_builtins.str] value: The content of the DNS record. The expected value depends on the record type:
                 * For A records: IPv4 address (e.g., '192.168.1.10')
                 * For AAAA records: IPv6 address
                 * For CNAME records: Canonical name (e.g., 'server1.example.com')
                 * For MX records: Mail server hostname
                 * For TXT records: Text content (e.g., 'v=spf1 include:_spf.example.com ~all')
        :param pulumi.Input[_builtins.int] weight: A relative weight for SRV records with the same priority. Higher values get proportionally more traffic. Only used with SRV records.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RecordState.__new__(_RecordState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["port"] = port
        __props__.__dict__["priority"] = priority
        __props__.__dict__["site"] = site
        __props__.__dict__["ttl"] = ttl
        __props__.__dict__["type"] = type
        __props__.__dict__["value"] = value
        __props__.__dict__["weight"] = weight
        return Record(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the DNS record is active. Defaults to true. Set to false to temporarily disable resolution without removing the record.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        DNS record name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[_builtins.int]:
        """
        The port number for SRV records. Valid values are between 1 and 65535. Only used with SRV records.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def priority(self) -> pulumi.Output[_builtins.int]:
        """
        Priority value for MX and SRV records. Lower values indicate higher priority. Required for MX and SRV records, ignored for other types.
        """
        return pulumi.get(self, "priority")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> pulumi.Output[_builtins.int]:
        """
        Time To Live (TTL) in seconds, determines how long DNS resolvers should cache this record. Set to 0 for automatic TTL. Common values: 300 (5 minutes), 3600 (1 hour), 86400 (1 day).
        """
        return pulumi.get(self, "ttl")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of DNS record. Valid values are:
          * `A` - Maps a hostname to IPv4 address
          * `AAAA` - Maps a hostname to IPv6 address
          * `CNAME` - Creates an alias for another domain name
          * `MX` - Specifies mail servers for the domain
          * `NS` - Delegates a subdomain to a set of name servers
          * `PTR` - Creates a pointer to a canonical name (reverse DNS)
          * `SOA` - Specifies authoritative information about the domain
          * `SRV` - Specifies location of services (hostname and port)
          * `TXT` - Holds descriptive text
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[_builtins.str]:
        """
        The content of the DNS record. The expected value depends on the record type:
          * For A records: IPv4 address (e.g., '192.168.1.10')
          * For AAAA records: IPv6 address
          * For CNAME records: Canonical name (e.g., 'server1.example.com')
          * For MX records: Mail server hostname
          * For TXT records: Text content (e.g., 'v=spf1 include:_spf.example.com ~all')
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter
    def weight(self) -> pulumi.Output[_builtins.int]:
        """
        A relative weight for SRV records with the same priority. Higher values get proportionally more traffic. Only used with SRV records.
        """
        return pulumi.get(self, "weight")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAccountResult',
    'AwaitableGetAccountResult',
    'get_account',
    'get_account_output',
]

@pulumi.output_type
class GetAccountResult:
    """
    A collection of values returned by getAccount.
    """
    def __init__(__self__, id=None, name=None, network_id=None, password=None, site=None, tunnel_medium_type=None, tunnel_type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_id and not isinstance(network_id, str):
            raise TypeError("Expected argument 'network_id' to be a str")
        pulumi.set(__self__, "network_id", network_id)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if site and not isinstance(site, str):
            raise TypeError("Expected argument 'site' to be a str")
        pulumi.set(__self__, "site", site)
        if tunnel_medium_type and not isinstance(tunnel_medium_type, int):
            raise TypeError("Expected argument 'tunnel_medium_type' to be a int")
        pulumi.set(__self__, "tunnel_medium_type", tunnel_medium_type)
        if tunnel_type and not isinstance(tunnel_type, int):
            raise TypeError("Expected argument 'tunnel_type' to be a int")
        pulumi.set(__self__, "tunnel_type", tunnel_type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this account.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the account to look up
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkId")
    def network_id(self) -> _builtins.str:
        """
        ID of the network for this account
        """
        return pulumi.get(self, "network_id")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        """
        The password of the account.
        """
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter
    def site(self) -> _builtins.str:
        """
        The name of the site the account is associated with.
        """
        return pulumi.get(self, "site")

    @_builtins.property
    @pulumi.getter(name="tunnelMediumType")
    def tunnel_medium_type(self) -> _builtins.int:
        """
        See RFC2868 section 3.2
        """
        return pulumi.get(self, "tunnel_medium_type")

    @_builtins.property
    @pulumi.getter(name="tunnelType")
    def tunnel_type(self) -> _builtins.int:
        """
        See RFC2868 section 3.1
        """
        return pulumi.get(self, "tunnel_type")


class AwaitableGetAccountResult(GetAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountResult(
            id=self.id,
            name=self.name,
            network_id=self.network_id,
            password=self.password,
            site=self.site,
            tunnel_medium_type=self.tunnel_medium_type,
            tunnel_type=self.tunnel_type)


def get_account(name: Optional[_builtins.str] = None,
                site: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountResult:
    """
    unifi_account data source can be used to retrieve RADIUS user accounts


    :param _builtins.str name: The name of the account to look up
    :param _builtins.str site: The name of the site the account is associated with.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('unifi:index/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult).value

    return AwaitableGetAccountResult(
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        network_id=pulumi.get(__ret__, 'network_id'),
        password=pulumi.get(__ret__, 'password'),
        site=pulumi.get(__ret__, 'site'),
        tunnel_medium_type=pulumi.get(__ret__, 'tunnel_medium_type'),
        tunnel_type=pulumi.get(__ret__, 'tunnel_type'))
def get_account_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                       site: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountResult]:
    """
    unifi_account data source can be used to retrieve RADIUS user accounts


    :param _builtins.str name: The name of the account to look up
    :param _builtins.str site: The name of the site the account is associated with.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['site'] = site
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('unifi:index/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult)
    return __ret__.apply(lambda __response__: GetAccountResult(
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        network_id=pulumi.get(__response__, 'network_id'),
        password=pulumi.get(__response__, 'password'),
        site=pulumi.get(__response__, 'site'),
        tunnel_medium_type=pulumi.get(__response__, 'tunnel_medium_type'),
        tunnel_type=pulumi.get(__response__, 'tunnel_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['CountryArgs', 'Country']

@pulumi.input_type
class CountryArgs:
    def __init__(__self__, *,
                 code: pulumi.Input[_builtins.str],
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Country resource.
        :param pulumi.Input[_builtins.str] code: The country code to set for the UniFi site. The country code must be a valid ISO 3166-1 alpha-2 code.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        pulumi.set(__self__, "code", code)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def code(self) -> pulumi.Input[_builtins.str]:
        """
        The country code to set for the UniFi site. The country code must be a valid ISO 3166-1 alpha-2 code.
        """
        return pulumi.get(self, "code")

    @code.setter
    def code(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "code", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _CountryState:
    def __init__(__self__, *,
                 code: Optional[pulumi.Input[_builtins.str]] = None,
                 code_numeric: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Country resources.
        :param pulumi.Input[_builtins.str] code: The country code to set for the UniFi site. The country code must be a valid ISO 3166-1 alpha-2 code.
        :param pulumi.Input[_builtins.int] code_numeric: The numeric representation in ISO 3166-1 of the country code.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        if code is not None:
            pulumi.set(__self__, "code", code)
        if code_numeric is not None:
            pulumi.set(__self__, "code_numeric", code_numeric)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def code(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The country code to set for the UniFi site. The country code must be a valid ISO 3166-1 alpha-2 code.
        """
        return pulumi.get(self, "code")

    @code.setter
    def code(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "code", value)

    @_builtins.property
    @pulumi.getter(name="codeNumeric")
    def code_numeric(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The numeric representation in ISO 3166-1 of the country code.
        """
        return pulumi.get(self, "code_numeric")

    @code_numeric.setter
    def code_numeric(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "code_numeric", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.type_token("unifi:setting/country:Country")
class Country(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 code: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `setting.Country` resource allows you to configure the country settings for your UniFi network.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example = unifi.setting.Country("example", code="US")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] code: The country code to set for the UniFi site. The country code must be a valid ISO 3166-1 alpha-2 code.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CountryArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `setting.Country` resource allows you to configure the country settings for your UniFi network.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        example = unifi.setting.Country("example", code="US")
        ```

        :param str resource_name: The name of the resource.
        :param CountryArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CountryArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 code: Optional[pulumi.Input[_builtins.str]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CountryArgs.__new__(CountryArgs)

            if code is None and not opts.urn:
                raise TypeError("Missing required property 'code'")
            __props__.__dict__["code"] = code
            __props__.__dict__["site"] = site
            __props__.__dict__["code_numeric"] = None
        super(Country, __self__).__init__(
            'unifi:setting/country:Country',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            code: Optional[pulumi.Input[_builtins.str]] = None,
            code_numeric: Optional[pulumi.Input[_builtins.int]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None) -> 'Country':
        """
        Get an existing Country resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] code: The country code to set for the UniFi site. The country code must be a valid ISO 3166-1 alpha-2 code.
        :param pulumi.Input[_builtins.int] code_numeric: The numeric representation in ISO 3166-1 of the country code.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CountryState.__new__(_CountryState)

        __props__.__dict__["code"] = code
        __props__.__dict__["code_numeric"] = code_numeric
        __props__.__dict__["site"] = site
        return Country(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def code(self) -> pulumi.Output[_builtins.str]:
        """
        The country code to set for the UniFi site. The country code must be a valid ISO 3166-1 alpha-2 code.
        """
        return pulumi.get(self, "code")

    @_builtins.property
    @pulumi.getter(name="codeNumeric")
    def code_numeric(self) -> pulumi.Output[_builtins.int]:
        """
        The numeric representation in ISO 3166-1 of the country code.
        """
        return pulumi.get(self, "code_numeric")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this resource should be applied. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[_builtins.int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[_builtins.str] name: A descriptive name for the user group (e.g., 'Staff', 'Guests', 'IoT Devices'). This name will be displayed in the UniFi controller interface and used when assigning clients to the group.
        :param pulumi.Input[_builtins.int] qos_rate_max_down: The maximum allowed download speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.int] qos_rate_max_up: The maximum allowed upload speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user group should be created. If not specified, the default site will be used.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if qos_rate_max_down is not None:
            pulumi.set(__self__, "qos_rate_max_down", qos_rate_max_down)
        if qos_rate_max_up is not None:
            pulumi.set(__self__, "qos_rate_max_up", qos_rate_max_up)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A descriptive name for the user group (e.g., 'Staff', 'Guests', 'IoT Devices'). This name will be displayed in the UniFi controller interface and used when assigning clients to the group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="qosRateMaxDown")
    def qos_rate_max_down(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum allowed download speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_down")

    @qos_rate_max_down.setter
    def qos_rate_max_down(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "qos_rate_max_down", value)

    @_builtins.property
    @pulumi.getter(name="qosRateMaxUp")
    def qos_rate_max_up(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum allowed upload speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_up")

    @qos_rate_max_up.setter
    def qos_rate_max_up(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "qos_rate_max_up", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this user group should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[_builtins.int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[_builtins.str] name: A descriptive name for the user group (e.g., 'Staff', 'Guests', 'IoT Devices'). This name will be displayed in the UniFi controller interface and used when assigning clients to the group.
        :param pulumi.Input[_builtins.int] qos_rate_max_down: The maximum allowed download speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.int] qos_rate_max_up: The maximum allowed upload speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user group should be created. If not specified, the default site will be used.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if qos_rate_max_down is not None:
            pulumi.set(__self__, "qos_rate_max_down", qos_rate_max_down)
        if qos_rate_max_up is not None:
            pulumi.set(__self__, "qos_rate_max_up", qos_rate_max_up)
        if site is not None:
            pulumi.set(__self__, "site", site)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A descriptive name for the user group (e.g., 'Staff', 'Guests', 'IoT Devices'). This name will be displayed in the UniFi controller interface and used when assigning clients to the group.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="qosRateMaxDown")
    def qos_rate_max_down(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum allowed download speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_down")

    @qos_rate_max_down.setter
    def qos_rate_max_down(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "qos_rate_max_down", value)

    @_builtins.property
    @pulumi.getter(name="qosRateMaxUp")
    def qos_rate_max_up(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum allowed upload speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_up")

    @qos_rate_max_up.setter
    def qos_rate_max_up(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "qos_rate_max_up", value)

    @_builtins.property
    @pulumi.getter
    def site(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the UniFi site where this user group should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

    @site.setter
    def site(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "site", value)


@pulumi.type_token("unifi:iam/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[_builtins.int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `iam.Group` resource manages client groups in the UniFi controller, which allow you to apply common settings and restrictions to multiple network clients.

        User groups are primarily used for:
          * Implementing Quality of Service (QoS) policies
          * Setting bandwidth limits for different types of users
          * Organizing clients into logical groups (e.g., Staff, Guests, IoT devices)

        Key features include:
          * Download rate limiting
          * Upload rate limiting
          * Group-based policy application

        User groups are particularly useful in:
          * Educational environments (different policies for staff and students)
          * Guest networks (limiting guest bandwidth)
          * Shared office spaces (managing different tenant groups)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        wifi = unifi.iam.Group("wifi",
            name="wifi",
            qos_rate_max_down=2000,
            qos_rate_max_up=10)
        ```

        ## Import

        import using the ID

        ```sh
        $ pulumi import unifi:iam/group:Group wifi 5fe6261995fe130013456a36
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: A descriptive name for the user group (e.g., 'Staff', 'Guests', 'IoT Devices'). This name will be displayed in the UniFi controller interface and used when assigning clients to the group.
        :param pulumi.Input[_builtins.int] qos_rate_max_down: The maximum allowed download speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.int] qos_rate_max_up: The maximum allowed upload speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user group should be created. If not specified, the default site will be used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[GroupArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `iam.Group` resource manages client groups in the UniFi controller, which allow you to apply common settings and restrictions to multiple network clients.

        User groups are primarily used for:
          * Implementing Quality of Service (QoS) policies
          * Setting bandwidth limits for different types of users
          * Organizing clients into logical groups (e.g., Staff, Guests, IoT devices)

        Key features include:
          * Download rate limiting
          * Upload rate limiting
          * Group-based policy application

        User groups are particularly useful in:
          * Educational environments (different policies for staff and students)
          * Guest networks (limiting guest bandwidth)
          * Shared office spaces (managing different tenant groups)

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_unifi as unifi

        wifi = unifi.iam.Group("wifi",
            name="wifi",
            qos_rate_max_down=2000,
            qos_rate_max_up=10)
        ```

        ## Import

        import using the ID

        ```sh
        $ pulumi import unifi:iam/group:Group wifi 5fe6261995fe130013456a36
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 qos_rate_max_down: Optional[pulumi.Input[_builtins.int]] = None,
                 qos_rate_max_up: Optional[pulumi.Input[_builtins.int]] = None,
                 site: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["name"] = name
            __props__.__dict__["qos_rate_max_down"] = qos_rate_max_down
            __props__.__dict__["qos_rate_max_up"] = qos_rate_max_up
            __props__.__dict__["site"] = site
        super(Group, __self__).__init__(
            'unifi:iam/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            qos_rate_max_down: Optional[pulumi.Input[_builtins.int]] = None,
            qos_rate_max_up: Optional[pulumi.Input[_builtins.int]] = None,
            site: Optional[pulumi.Input[_builtins.str]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] name: A descriptive name for the user group (e.g., 'Staff', 'Guests', 'IoT Devices'). This name will be displayed in the UniFi controller interface and used when assigning clients to the group.
        :param pulumi.Input[_builtins.int] qos_rate_max_down: The maximum allowed download speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.int] qos_rate_max_up: The maximum allowed upload speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        :param pulumi.Input[_builtins.str] site: The name of the UniFi site where this user group should be created. If not specified, the default site will be used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["name"] = name
        __props__.__dict__["qos_rate_max_down"] = qos_rate_max_down
        __props__.__dict__["qos_rate_max_up"] = qos_rate_max_up
        __props__.__dict__["site"] = site
        return Group(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        A descriptive name for the user group (e.g., 'Staff', 'Guests', 'IoT Devices'). This name will be displayed in the UniFi controller interface and used when assigning clients to the group.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="qosRateMaxDown")
    def qos_rate_max_down(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum allowed download speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_down")

    @_builtins.property
    @pulumi.getter(name="qosRateMaxUp")
    def qos_rate_max_up(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        The maximum allowed upload speed in Kbps (kilobits per second) for clients in this group. Set to -1 for unlimited. Note: Values of 0 or 1 are not allowed. Defaults to `-1`.
        """
        return pulumi.get(self, "qos_rate_max_up")

    @_builtins.property
    @pulumi.getter
    def site(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the UniFi site where this user group should be created. If not specified, the default site will be used.
        """
        return pulumi.get(self, "site")

